@@ -13,8 +13,12 @@ use Net::Async::IRC;
 GetOptions(
    'server|s=s' => \my $SERVER,
    'nick|n=s'   => \my $NICK,
+   'port|p=i'   => \my $PORT,
+   'SSL|S'      => \my $SSL,
 ) or exit 1;
 
+require IO::Async::SSL if $SSL;
+
 my $loop = IO::Async::Loop->new;
 
 my $irc = Net::Async::IRC->new(
@@ -30,8 +34,20 @@ my $irc = Net::Async::IRC->new(
 );
 $loop->add( $irc );
 
+$PORT //= ( $SSL ? 6697 : 6667 );
+
+$irc->connect(
+   host    => $SERVER,
+   service => $PORT,
+   ( $SSL ?
+      ( extensions => ['SSL'],
+        SSL_verify_mode => 0 ) :
+      () ),
+)->get;
+
+print "Connected...\n";
+
 $irc->login(
-   host => $SERVER,
    nick => $NICK,
 )->get;
 
